//
//  NSBundle+RCUtils.m
//  RCIMKitDemo
//
//  Created by zhiheng on 2018/7/10.
//  Copyright © 2018年 com.wc. All rights reserved.
//

#import "NSBundle+RCUtils.h"
#import "RCLanguageConfig.h"
#import <objc/runtime.h>

@interface RCBundle : NSBundle

@end

@implementation NSBundle (RCUtils)


// 获取App 内部设置的语言,如果未设置过，则 默认为系统语言
+ (NSString *)currentLanguage
{
    return [RCLanguageConfig userLanguage] ? : [NSLocale preferredLanguages].firstObject;
}

+ (void)load
{
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        //动态继承、交换，方法类似KVO，通过修改[NSBundle mainBundle]对象的isa指针，使其指向它的子类RCBundle，这样便可以调用子类的方法；其实这里也可以使用method_swizzling来交换mainBundle的实现，来动态判断，可以同样实现。
        object_setClass([NSBundle mainBundle], [RCBundle class]);
    });
}

@end

@implementation RCBundle

- (NSString *)localizedStringForKey:(NSString *)key value:(NSString *)value table:(NSString *)tableName
{
    if ([RCBundle rc_mainBundle]) {
        // 通过修改[NSBundle mainBundle]对象的isa指针，使其指向它的子类RCBundle
        return [[RCBundle rc_mainBundle] localizedStringForKey:key value:value table:tableName];
    } else {
        return [super localizedStringForKey:key value:value table:tableName];
    }
}

+ (NSBundle *)rc_mainBundle
{
    if ([NSBundle currentLanguage].length) {
        NSString *path = [[NSBundle mainBundle] pathForResource:[NSBundle currentLanguage] ofType:@"lproj"];
        if (path.length) {
            return [NSBundle bundleWithPath:path];
        }else{
            NSLog(@"不支持所选择App内置语言");
        }
    }

    return nil;
}
@end
